/* fix_capitalization.C

   Copyright (C) 1999 by David Rose.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

   To contact the original author of this program, write to:
           David Rose
           224 W. Dryden St Apt. 418
	   Glendale, CA 91202
	   USA

	   drose@lafn.org
   */

#include "system.h"
#include "fix_capitalization.h"
#include "extract_words.h"
#include "string_utils.h"

string
fix_capitalization(const string &str) {
  string result;
  bool start_word = true;
  for (int i = 0; i < str.length(); i++) {
    if (isspace(str[i])) {
      start_word = true;
      result += str[i];

    } else if (!isalpha(str[i])) {
      result += str[i];

    } else if (start_word) {
      // We don't capitalize any "unimportant words".  Otherwise, we
      // capitalize each word.  (But we do capitalize an article if it
      // is the very first word!)
      string word = make_upper(extract_first_word(str.substr(i)));
      if (i != 0 && (word == "A" || word == "AN" || word == "THE" ||
		     word == "OF" || word == "TO" || word == "IN")) {
	result += tolower(str[i]);
      } else {
	result += toupper(str[i]);
      }
      start_word = false;

    } else {
      result += tolower(str[i]);
    }
  }

  return result;
}
